@@ -23,6 +23,7 @@ has body => (
     isa     => 'Any',
     default => '',
 );
+sub content { shift->body(@_) } # alias
 
 has cookies => (
     is      => 'rw',
@@ -41,6 +42,8 @@ has status => (
     default => 200,
 );
 
+sub code { shift->status(@_) }
+
 has headers => (
     is      => 'rw',
     isa     => Header,
