@@ -1,7 +1,7 @@
 package HTTP::Engine::Role::ResponseWriter;
 use Moose::Role;
 
-requires qw(finalize write output_body);
+requires qw(finalize);
 
 1;
 
